
#ifndef _C14_ds658_
#define _C14_ds658_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F1195_8501(EIF_REFERENCE);
extern void EIF_Minit658(void);
extern char *(*R6552[])();

#ifdef __cplusplus
}
#endif

#endif
